@@ -1343,7 +1343,8 @@ class Scene(Geometry3D):
         viewer : Union[str, callable, None]
           What kind of viewer to use, such as
           'gl' to open a pyglet window, 'notebook'
-          for a jupyter notebook or None
+          for a jupyter notebook, 'marimo' for
+          a marimo notebook or None
         kwargs : dict
           Includes `smooth`, which will turn
           on or off automatic smooth shading
@@ -1353,9 +1354,9 @@ class Scene(Geometry3D):
             # check to see if we are in a notebook or not
             from ..viewer import in_notebook
 
-            if in_notebook():
-                viewer = "notebook"
-            else:
+            # returns a literal for what kind of notebook, or False
+            viewer = in_notebook()
+            if not viewer:
                 viewer = "gl"
 
         if viewer == "gl":
@@ -1364,10 +1365,14 @@ class Scene(Geometry3D):
             from ..viewer import SceneViewer
 
             return SceneViewer(self, **kwargs)
-        elif viewer == "notebook":
+        elif viewer == "jupyter":
             from ..viewer import scene_to_notebook
 
             return scene_to_notebook(self, **kwargs)
+        elif viewer == "marimo":
+            from ..viewer import scene_to_mo_notebook
+
+            return scene_to_mo_notebook(self, **kwargs)
         elif callable(viewer):
             # if a callable method like a custom class
             # constructor was passed run using that
